/*
***********************************************************************************************
* 										Hello World
* Hardware :	PIC24_Eval1
* File:			..\PIC24_Eval1\HelloWorld\helloworld.c
* Functions: 	This project is the first demo program for development board PIC24_Eval-B1
* Date: 		6 Nov 2007
* Version:		1.0a
* Programmer: 	John Leung at TechToys Co.(www.TechToys.com.hk)
*
*										Description
* Beyond a simple LED blinky project, this program also demonstrates the internal clock RC clock
* feature of the PIC24 microcontroller.
* The oscillator source that is used at a device power-on reset is selected using Configuration 
* bit settings (extracted from PIC24FJ128GA manual).
* The configuration word 2 is more important for us in this example
* The default configuration for FNOSC2:FNOSC0 is 1:1:1 (Fast RC Oscillator with Postscaler)
* The postscaler value is configured in register CLKDIV, with default value RCDIV2:RCDIV0 = 0:1:1
* This gives a clock speed of 1MHz(divided by 8). Therefore, if we didn't configure the FNOSC values,
* the clock source of the mcu would be given by FRC oscillator at 8MHz with a postscaler divided by 8, 
* giving a Fosc value of 1MHz with cpu peripheral clock ratio set to 1:1.
* If we want to set a faster cpu speed without using an external crystal, we need to use the PLL (x4).
* This can be done by using the configuration marco _CONFIG2(FNOSC_FRCPLL) provided by mcc30 compiler.
* The result is a cpu clock speed of 4MHz (8MHz*4 divided by the post scaler 8).
* The full speed of the mcu can be achieved by setting RCDIV2:RCDIV0 to 000 (divide by 1).
* In this case, Fosc would be 32MHz. 
* There is an easy way to monitor the cpu clock speed by setting RC15 pin to OSCO (Fosc/2). This can be 
* done by using the _CONFIG2 configuration macro with an argument OSCIOFNC_OFF. If RC15 digital IO 
* function is required, we just use the complementary argument OSCIOFNC_ON to get it back.
* A Logic Anayzer is used to probe the waveforms for timing
***********************************************************************************************
*/

#include <p24fj128ga010.h>

//JTAG OFF and WDT OFF (refer to p24FJ128GA010.h for arguments available)
_CONFIG1(JTAGEN_OFF & FWDTEN_OFF)
//configure fast RC oscillator with PLL and RC15 pin for Fosc/2 function		
_CONFIG2(FNOSC_FRCPLL & OSCIOFNC_OFF)

/*
********************************************************************************************************
*											Main
********************************************************************************************************
*/
int main (void)
{
	CLKDIV = 0x0000;		//FRC postscaler divided by 1 (8MHz from internal RC)

	TRISA = 0;
	for(;;){
		PORTA = 0xC5;
		PORTA = 0x38;
		PORTA = 0x47;		
	}

	return (0);
}
